﻿using Borepin.Model;
using Borepin.Service.BFFH;
using Borepin.Service.Connections;
using Prism.Mvvm;
using Prism.Navigation;
using System.Threading.Tasks;
using System.Windows.Input;
using Xamarin.Forms;

namespace Borepin.PageModel
{
    public class LoginPasswordPageModel : BindableBase
    {
        private INavigationService _NavigationService;
        private IBFFHService _BFFHService;
        private IConnectionService _ConnectionService;

        private string _KnownUsername;

        public LoginPasswordPageModel(INavigationService navigationService, IBFFHService bffhService, IConnectionService connectionService)
        {
            _NavigationService = navigationService;
            _BFFHService = bffhService;
            _ConnectionService = connectionService;

            AuthenticateCommand = new Command(AuthenticateCommandExecuted);

            Task.Run(LoadData);
        }

        private void LoadData()
        {
            _KnownUsername = _BFFHService.ActiveConnection.Username;

            if (_KnownUsername != null)
            {
                Username = _KnownUsername;
                Password = "********";
            }
        }

        private string _Username;
        public string Username
        {
            get => _Username;
            set => SetProperty(ref _Username, value);
        }

        private string _Password;
        public string Password
        {
            get => _Password;
            set => SetProperty(ref _Password, value);
        }

        private ICommand _AuthenticateCommand;
        public ICommand AuthenticateCommand
        {
            get => _AuthenticateCommand;
            set => SetProperty(ref _AuthenticateCommand, value);
        }

        private async void AuthenticateCommandExecuted()
        {
            if(_KnownUsername == Username)
            {
                await _BFFHService.Authenticate();
                await _ConnectionService.LogConnect(_BFFHService.ActiveConnection);
            }
            else
            {
                Connection connection_update = _BFFHService.ActiveConnection;

                connection_update.Username = Username;
                await _BFFHService.Authenticate(connection_update, Password);

                await _ConnectionService.AddConnection(_BFFHService.ActiveConnection);
                await _ConnectionService.LogConnect(_BFFHService.ActiveConnection);
            }

            var result = await _NavigationService.NavigateAsync("/MainPage/NavigationPage/MachinesPage");

            if (!result.Success)
            {
                System.Diagnostics.Debugger.Break();
            }
        }
    }
}
